@@ -1,8 +1,10 @@
 import os
 import platform
+from typing import Optional
 
 from requests.structures import CaseInsensitiveDict
 
+from ytmusicapi.exceptions import YTMusicError, YTMusicUserError
 from ytmusicapi.helpers import *
 
 path = os.path.dirname(os.path.realpath(__file__)) + os.sep
@@ -13,7 +15,7 @@ def is_browser(headers: CaseInsensitiveDict) -> bool:
     return all(key in headers for key in browser_structure)
 
 
-def setup_browser(filepath=None, headers_raw=None):
+def setup_browser(filepath: Optional[str] = None, headers_raw: Optional[str] = None) -> str:
     contents = []
     if not headers_raw:
         eof = "Ctrl-D" if platform.system() != "Windows" else "'Enter, Ctrl-Z, Enter'"
@@ -45,12 +47,13 @@ def setup_browser(filepath=None, headers_raw=None):
             user_headers[header[0].lower()] = ": ".join(header[1:])
 
     except Exception as e:
-        raise Exception(f"Error parsing your input, please try again. Full error: {e}") from e
+        raise YTMusicError(f"Error parsing your input, please try again. Full error: {e}") from e
 
     missing_headers = {"cookie", "x-goog-authuser"} - set(k.lower() for k in user_headers.keys())
     if missing_headers:
-        raise Exception(
-            "The following entries are missing in your headers: " + ", ".join(missing_headers)
+        raise YTMusicUserError(
+            "The following entries are missing in your headers: "
+            + ", ".join(missing_headers)
             + ". Please try a different request (such as /browse) and make sure you are logged in."
         )
 
